import 'package:cs_resources/constants/color_constants.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/widget_export.dart';

import 'attendance_review_item.dart';
import 'attendance_review_controller.dart';

import 'package:plugin_basic/base/base_state.dart';
import 'package:plugin_basic/base/base_stateful_page.dart';
import 'package:plugin_basic/utils/ext_get_nav.dart';
import 'package:router/path/router_path.dart';
import 'package:shared/utils/screen_util.dart';
import 'package:widgets/my_appbar.dart';
import 'attendance_review_state.dart';

/*
 * 工作考勤的审核列表
 */
class AttendanceReviewPage extends BaseStatefulPage<AttendanceReviewController> {
  AttendanceReviewPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance() {
    return Get.start(RouterPath.jobAttendanceReviewList);
  }

  @override
  AttendanceReviewController createRawController() {
    return AttendanceReviewController();
  }

  @override
  State<AttendanceReviewPage> createState() => _LabourReviewState();
}

class _LabourReviewState extends BaseState<AttendanceReviewPage, AttendanceReviewController> {
  late AttendanceReviewState state;

  @override
  void initState() {
    super.initState();
    state = controller.state;
  }

  @override
  Widget build(BuildContext context) {
    return autoCtlGetBuilder(builder: (controller) {
      return SafeArea(
        bottom: true,
        top: false,
        child: Container(
          width: double.infinity,
          height: double.infinity,
          padding: EdgeInsets.only(top: ScreenUtil.getStatusBarH(context)),
          decoration: const BoxDecoration(
            gradient: LinearGradient(
              colors: [
                Color(0xFF091D44),
                Color(0xFF245A8A),
                Color(0xFF7F7CEC),
              ],
              begin: Alignment.topCenter,
              end: Alignment.bottomCenter,
            ),
          ),
          child: Column(
            children: [
              MyAppBar.searchTitleBar(
                context,
                value: state.keyword,
                hintText: 'Title'.tr,
                controller: state.searchController,
                onSearch: (keyword) {
                  controller.doSearch(keyword);
                },
                actions: [
                  //重置按钮
                  MyButton(
                    onPressed: () {
                      FocusScope.of(context).unfocus();
                      controller.resetFiltering();
                    },
                    text: "Reset".tr,
                    textColor: ColorConstants.white,
                    backgroundColor: hexToColor("#2BA9F9", opacity: 0.5),
                    radius: 17.25,
                    minWidth: 60,
                    minHeight: 35,
                  ).marginOnly(right: 15),

                ],
              ),

              //底部的列表
              EasyRefresh(
                controller: controller.refreshController,
                onRefresh: controller.onRefresh,
                onLoad: controller.loadMore,
                child: LoadStateLayout(
                  state: controller.loadingState,
                  errorMessage: controller.errorMessage,
                  errorRetry: () {
                    controller.retryRequest();
                  },
                  successSliverWidget: [
                    SliverList(
                        delegate: SliverChildBuilderDelegate(
                      (context, index) {
                        return AttendanceReviewItem(
                          index: index,
                          item: state.datas[index],
                          onStatusAction: () {

                          },
                          onItemAction: () {
                            controller.doSelectedOrNot(state.datas[index]);
                          },
                        );
                      },
                      childCount: state.datas.length,
                    ))
                  ],
                ),
              ).expanded(),

              Row(
                mainAxisSize: MainAxisSize.max,
                children: [
                  //批量Approve
                  MyTextView(
                    "Batch Confirm".tr,
                    fontSize: 17,
                    isFontMedium: true,
                    boxHeight: 48,
                    onClick: () {
                      controller.operationApprove();
                    },
                    alignment: Alignment.center,
                    textAlign: TextAlign.center,
                    textColor: Colors.white,
                    backgroundColor: ColorConstants.textGreen0AC074,
                  ).expanded(),

                  //批量修改时间
                  MyTextView(
                    "Batch Reject".tr,
                    fontSize: 17,
                    isFontMedium: true,
                    boxHeight: 48,
                    onClick: () {
                      controller.operationReject();
                    },
                    alignment: Alignment.center,
                    textAlign: TextAlign.center,
                    textColor: Colors.white,
                    backgroundColor: ColorConstants.textRedFF6262,
                  ).expanded(),
                ],
              ),
            ],
          ),
        ),
      );
    });
  }
}
