import 'package:cs_resources/constants/color_constants.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/search_app_bar.dart';
import 'package:widgets/widget_export.dart';

import 'applied_staff_add.dart';
import 'applied_staff_controller.dart';

import 'package:plugin_basic/base/base_state.dart';
import 'package:plugin_basic/base/base_stateful_page.dart';
import 'package:plugin_basic/utils/ext_get_nav.dart';
import 'package:router/path/router_path.dart';
import 'package:shared/utils/screen_util.dart';
import 'package:widgets/my_appbar.dart';
import 'applied_staff_state.dart';

/**
 * 已申请的页面，添加员工页面
 */
class AppliedStaffPage extends BaseStatefulPage<AppliedStaffController> {
  AppliedStaffPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance(String? jobId) {
    return Get.start(RouterPath.jobListAppliedStaffListSG, arguments: {'jobId': jobId});
  }

  @override
  AppliedStaffController createRawController() {
    return AppliedStaffController();
  }

  @override
  State<AppliedStaffPage> createState() => _AppliedStaffState();
}

class _AppliedStaffState extends BaseState<AppliedStaffPage, AppliedStaffController> {
  late AppliedStaffState state;

  @override
  void initState() {
    super.initState();
    state = controller.state;
    state.jobId = Get.arguments['jobId'];
  }

  @override
  Widget build(BuildContext context) {
    return autoCtlGetBuilder(builder: (controller) {
      return SafeArea(
        bottom: true,
        top: false,
        child: Container(
          width: double.infinity,
          height: double.infinity,
          padding: EdgeInsets.only(top: ScreenUtil.getStatusBarH(context)),
          decoration: const BoxDecoration(
            gradient: LinearGradient(
              colors: [
                Color(0xFF091D44),
                Color(0xFF245A8A),
                Color(0xFF7F7CEC),
              ],
              begin: Alignment.topCenter,
              end: Alignment.bottomCenter,
            ),
          ),
          child: Column(
            children: [
              MyAppBar.titleBar(
                context,
                "Add Staff - Choose Staff".tr,
              ),

              //搜索的条件
              Row(
                children: [
                  SearchAppBar(
                    value: state.keyword,
                    onSearch: (keyword) {
                      controller.doSearch(keyword);
                    },
                    hintText: "Name / Nric".tr,
                    controller: state.searchController,
                  ).expanded(),
                  MyButton(
                    onPressed: () {
                      FocusScope.of(context).unfocus();
                      controller.resetFiltering();
                    },
                    text: "Reset".tr,
                    textColor: ColorConstants.white,
                    backgroundColor: hexToColor("#2BA9F9", opacity: 0.5),
                    radius: 20,
                    minWidth: 60,
                    minHeight: 35,
                  ),
                ],
              ).marginOnly(top: 10, left: 15, right: 15, bottom: 5),

              //底部的列表
              EasyRefresh(
                controller: controller.refreshController,
                onRefresh: controller.onRefresh,
                onLoad: controller.loadMore,
                child: LoadStateLayout(
                  state: controller.loadingState,
                  errorMessage: controller.errorMessage,
                  errorRetry: () {
                    controller.retryRequest();
                  },
                  successSliverWidget: [
                    SliverList(
                        delegate: SliverChildBuilderDelegate(
                      (context, index) {
                        return AppliedStaffItem(
                          index: index,
                          item: state.datas[index],
                          onItemAction: () {
                            controller.doSelectedOrNot(state.datas[index]);
                          },
                        );
                      },
                      childCount: state.datas.length,
                    ))
                  ],
                ),
              ).expanded(),

              MyTextView(
                "Submit".tr,
                fontSize: 17,
                isFontMedium: true,
                boxHeight: 48,
                onClick: () {
                  controller.doSubmit();
                },
                alignment: Alignment.center,
                textAlign: TextAlign.center,
                textColor: Colors.white,
                backgroundColor: Color(0XFFFFBB1B),
              ),

            ],
          ),
        ),
      );
    });
  }
}
