import 'package:domain/entity/response/staff_remark_history_entity.dart';
import 'package:domain/entity/response/staff_review_history_s_g_entity.dart';
import 'package:domain/repository/job_sg_repository.dart';
import 'package:get/get.dart';
import 'package:plugin_platform/http/dio/dio_cancelable_mixin.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/widget_export.dart';

import 'applied_staff_reviews_state.dart';

class AppliedStaffReviewsController extends GetxController with DioCancelableMixin {
  final JobSGRepository _jobRepository = Get.find();
  final AppliedStaffReviewsState state = AppliedStaffReviewsState();

  var _curPage = 1;
  var _needShowPlaceholder = true;

  //页面PlaceHolder的展示
  LoadState loadingState = LoadState.State_Success;
  String? errorMessage;

  //刷新页面状态
  void changeLoadingState(LoadState state) {
    loadingState = state;
    update();
  }

  // Refresh 控制器
  final EasyRefreshController refreshController = EasyRefreshController(
    controlFinishRefresh: true,
    controlFinishLoad: true,
  );

  // Refresh 刷新事件
  Future onRefresh() async {
    _curPage = 1;
    fetchStaffReviews();
  }

  // Refresh 加载事件
  Future loadMore() async {
    _curPage++;
    fetchStaffReviews();
  }

  // 重试请求
  Future retryRequest() async {
    _curPage = 1;
    _needShowPlaceholder = true;
    fetchStaffReviews();
  }

  /// 获取列表数据
  Future fetchStaffReviews() async {
    if (_needShowPlaceholder) {
      changeLoadingState(LoadState.State_Loading);
    }

    var listResult = await _jobRepository.fetchStaffReviewHistory(state.memberId, curPage: _curPage, cancelToken: cancelToken);

    // 处理数据
    if (listResult.isSuccess) {
      handleList(listResult.data?.reviews);
    } else {
      errorMessage = listResult.errorMsg;
      changeLoadingState(LoadState.State_Error);
    }

    // 最后赋值
    _needShowPlaceholder = false;
  }

  // 处理数据与展示的逻辑
  void handleList(List<StaffReviewHistorySGReviews>? list) {
    if (list != null && list.isNotEmpty) {
      //有数据，判断是刷新还是加载更多的数据
      if (_curPage == 1) {
        //刷新的方式
        state.datas.clear();
        state.datas.addAll(list);
        refreshController.finishRefresh();

        //更新展示的状态
        changeLoadingState(LoadState.State_Success);
      } else {
        //加载更多
        state.datas.addAll(list);
        refreshController.finishLoad();
        update();
      }
    } else {
      if (_curPage == 1) {
        //展示无数据的布局
        state.datas.clear();
        changeLoadingState(LoadState.State_Empty);
        refreshController.finishRefresh();
      } else {
        //展示加载完成，没有更多数据了
        refreshController.finishLoad(IndicatorResult.noMore);
      }
    }
  }

  @override
  void onReady() {
    super.onReady();
    fetchStaffReviews();
  }
}
