import 'package:cs_resources/constants/color_constants.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:plugin_basic/base/base_state.dart';
import 'package:plugin_basic/base/base_stateful_page.dart';
import 'package:plugin_basic/utils/ext_get_nav.dart';
import 'package:router/path/router_path.dart';
import 'package:shared/utils/screen_util.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/widget_export.dart';

import 'revise_list_item.dart';
import 'revise_list_controller.dart';
import 'revise_list_state.dart';

/**
 * Revise的全部列表
 */
class ReviseListPage extends BaseStatefulPage<ReviseListController> {
  ReviseListPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance() {
    return Get.start(RouterPath.reviseListSG);
  }

  @override
  ReviseListController createRawController() {
    return ReviseListController();
  }

  @override
  State<ReviseListPage> createState() => _JobListState();
}

class _JobListState extends BaseState<ReviseListPage, ReviseListController> {
  late ReviseListState state;

  @override
  void initState() {
    super.initState();
    state = controller.state;
  }

  @override
  Widget build(BuildContext context) {
    return autoCtlGetBuilder(builder: (controller) {
      return SafeArea(
        bottom: true,
        top: false,
        child: Container(
          width: double.infinity,
          height: double.infinity,
          padding: EdgeInsets.only(top: ScreenUtil.getStatusBarH(context)),
          decoration: const BoxDecoration(
            gradient: LinearGradient(
              colors: [
                Color(0xFF091D44),
                Color(0xFF245A8A),
                Color(0xFF7F7CEC),
              ],
              begin: Alignment.topCenter,
              end: Alignment.bottomCenter,
            ),
          ),
          child: Column(
            children: [
              MyAppBar.searchTitleBar(
                context,
                value: state.keyword,
                hintText: 'Search'.tr,
                controller: state.searchController,
                onSearch: (keyword) {
                  controller.doSearch(keyword);
                },
                actions: [
                  //重置按钮
                  MyButton(
                    onPressed: () {
                      FocusScope.of(context).unfocus();
                      controller.resetFiltering();
                    },
                    text: "Reset".tr,
                    textColor: ColorConstants.white,
                    backgroundColor: hexToColor("#2BA9F9", opacity: 0.5),
                    radius: 17.25,
                    minWidth: 60,
                    minHeight: 35,
                  ).marginOnly(right: 15),

                  //筛选图标
                  MyAssetImage(
                    Assets.baseServiceTitleBarFilterIcon,
                    width: 24,
                    height: 16.5,
                  ).onTap(() {
                    FocusScope.of(context).unfocus();
                    controller.showFilterDialog();
                  }).marginOnly(right: 15),
                ],
              ),
              //底部的列表
              EasyRefresh(
                controller: controller.refreshController,
                onRefresh: controller.onRefresh,
                onLoad: controller.loadMore,
                child: LoadStateLayout(
                  state: controller.loadingState,
                  errorMessage: controller.errorMessage,
                  errorRetry: () {
                    controller.retryRequest();
                  },
                  successSliverWidget: [
                    SliverList(delegate: SliverChildBuilderDelegate((context, index) {
                        return ReviseListItem(
                          index: index,
                          item: state.datas[index],
                          onDetailAction: () {
                            controller.gotoReviseDetailPage(index);
                          },
                          onLogsAction: () {
                            controller.gotoReviseLogsPage(index);
                          },
                          onDeleteAction: () {
                            controller.doDeleteAction(index);
                          },
                          onRecallAction: () {
                            controller.doRecallAction(index);
                          },
                          onEditAction: () {
                            controller.gotoReviseEditPage(index);
                          },
                        );
                      },
                      childCount: state.datas.length,
                    ))
                  ],
                ),
              ).marginOnly(top: 5, bottom: 5).expanded(),
            ],
          ),
        ),
      );
    });
  }

}
