import 'package:cs_resources/constants/color_constants.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:plugin_basic/base/base_state.dart';
import 'package:plugin_basic/base/base_stateful_page.dart';
import 'package:plugin_basic/utils/ext_get_nav.dart';
import 'package:router/path/router_path.dart';
import 'package:shared/utils/screen_util.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/widget_export.dart';

import 'labour_request_item.dart';
import 'labour_request_list_controller.dart';
import 'labour_request_list_state.dart';

/**
 * 用工请求的主页列表
 */
class LabourRequestListPage extends BaseStatefulPage<LabourRequestListController> {
  LabourRequestListPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance() {
    return Get.start(RouterPath.jobLabourRequestList);
  }

  @override
  LabourRequestListController createRawController() {
    return LabourRequestListController();
  }

  @override
  State<LabourRequestListPage> createState() => _LabourRequestListState();
}

class _LabourRequestListState extends BaseState<LabourRequestListPage, LabourRequestListController> {
  late LabourRequestListState state;

  @override
  void initState() {
    super.initState();
    state = controller.state;
  }

  @override
  Widget build(BuildContext context) {
    return autoCtlGetBuilder(builder: (controller) {
      return SafeArea(
        bottom: true,
        top: false,
        child: Container(
          width: double.infinity,
          height: double.infinity,
          padding: EdgeInsets.only(top: ScreenUtil.getStatusBarH(context)),
          decoration: const BoxDecoration(
            gradient: LinearGradient(
              colors: [
                Color(0xFF091D44),
                Color(0xFF245A8A),
                Color(0xFF7F7CEC),
              ],
              begin: Alignment.topCenter,
              end: Alignment.bottomCenter,
            ),
          ),
          child: Column(
            children: [
              MyAppBar.searchTitleBar(
                context,
                value: state.keyword,
                hintText: 'Title'.tr,
                controller: state.searchController,
                onSearch: (keyword) {
                  controller.doSearch(keyword);
                },
                actions: [
                  //重置按钮
                  MyButton(
                    onPressed: () {
                      FocusScope.of(context).unfocus();
                      controller.resetFiltering();
                    },
                    text: "Reset".tr,
                    textColor: ColorConstants.white,
                    backgroundColor: hexToColor("#2BA9F9", opacity: 0.5),
                    radius: 17.25,
                    minWidth: 60,
                    minHeight: 35,
                  ).marginOnly(right: 15),

                  //筛选图标
                  const MyAssetImage(
                    Assets.baseServiceTitleBarFilterIcon,
                    width: 24,
                    height: 16.5,
                  ).onTap(() {
                    FocusScope.of(context).unfocus();
                    controller.showFilterDialog();
                  }).marginOnly(right: 15),
                ],
              ),
              // 添加按钮
              MyButton(
                type: ClickType.throttle,
                milliseconds: 500,
                onPressed: () {
                  FocusScope.of(context).unfocus();
                  controller.gotoAddLabourPage();
                },
                text: "Create New Job Request".tr,
                textColor: ColorConstants.white,
                fontSize: 16,
                radius: 20,
                backgroundColor: hexToColor("#FFBB1B"),
                fontWeight: FontWeight.w500,
              ).marginSymmetric(horizontal: 15, vertical: 15),

              //底部的列表
              EasyRefresh(
                controller: controller.refreshController,
                onRefresh: controller.onRefresh,
                onLoad: controller.loadMore,
                child: LoadStateLayout(
                  state: controller.loadingState,
                  errorMessage: controller.errorMessage,
                  errorRetry: () {
                    controller.retryRequest();
                  },
                  successSliverWidget: [
                    SliverList(
                        delegate: SliverChildBuilderDelegate(
                      (context, index) {
                        return LabourRequestItem(
                          index: index,
                          item: state.datas[index],
                          onDetailAction: () {
                            controller.gotoDetailPage(state.datas[index]);
                          },
                          onRecallAction: () {
                            controller.doRecall(state.datas[index]);
                          },
                          onEditAction: () {
                            controller.gotoEditPage(state.datas[index]);
                          },
                          onStatusAction: () {
                            controller.gotoWorkflowPage(state.datas[index]);
                          },
                        );
                      },
                      childCount: state.datas.length,
                    ))
                  ],
                ),
              ).expanded(),
            ],
          ),
        ),
      );
    });
  }
}
