
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:plugin_basic/base/base_state.dart';
import 'package:plugin_basic/base/base_stateful_page.dart';
import 'package:plugin_basic/utils/ext_get_nav.dart';
import 'package:router/path/router_path.dart';
import 'package:shared/utils/screen_util.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/widget_export.dart';

import 'labour_request_workflow_controller.dart';
import 'labour_request_workflow_state.dart';
import 'labour_workflow_item.dart';

/**
 * 用工请求-状态工作流列表
 */
class LabourRequestWorkflowPage extends BaseStatefulPage<LabourRequestWorkflowController> {
  LabourRequestWorkflowPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance(String? requestId) {
    return Get.start(RouterPath.jobLabourRequestWorkflow,arguments: {'requestId': requestId});
  }

  @override
  LabourRequestWorkflowController createRawController() {
    return LabourRequestWorkflowController();
  }

  @override
  State<LabourRequestWorkflowPage> createState() => _LabourRequestWorkflowState();

}

class _LabourRequestWorkflowState extends BaseState<LabourRequestWorkflowPage, LabourRequestWorkflowController> {

  late LabourRequestWorkflowState state;

  @override
  void initState() {
    super.initState();
    state = controller.state;
    state.requestId = Get.arguments['requestId'];
  }

  @override
  Widget build(BuildContext context) {
    return autoCtlGetBuilder(builder: (controller) {
      return  SafeArea(
          bottom: true,
          top: false,
          child: Container(
            width: double.infinity,
            height: double.infinity,
            padding: EdgeInsets.only(top: ScreenUtil.getStatusBarH(context)),
            decoration: const BoxDecoration(
              gradient: LinearGradient(
                colors: [
                  Color(0xFF091D44),
                  Color(0xFF245A8A),
                  Color(0xFF7F7CEC),
                ],
                begin: Alignment.topCenter,
                end: Alignment.bottomCenter,
              ),
            ),
            child: Column(
              children: [
                MyAppBar.titleBar(context, "Workflow".tr),

                EasyRefresh(
                  controller: controller.refreshController,
                  onRefresh: controller.onRefresh,
                  child: LoadStateLayout(
                    state: controller.loadingState,
                    errorMessage: controller.errorMessage,
                    errorRetry: () {
                      controller.retryRequest();
                    },
                    successSliverWidget: [
                      SliverList(
                          delegate: SliverChildBuilderDelegate((context, index) {
                              return LabourWorkFlowItem(index: index,item: state.datas[index]);
                            },
                            childCount: state.datas.length,
                          ))
                    ],
                  ),
                ).expanded(),
              ],
            ).marginOnly(top: 10),
          ),
        );
    });
  }
}


