import 'package:domain/repository/labour_sg_repository.dart';
import 'package:flutter/cupertino.dart';
import 'package:get/get.dart';
import 'package:plugin_platform/engine/notify/notify_engine.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:plugin_platform/http/dio/dio_cancelable_mixin.dart';
import 'package:shared/utils/date_time_utils.dart';
import 'package:shared/utils/util.dart';
import 'package:widgets/picker/date_picker_util.dart';
import 'package:widgets/picker/option_pick_util.dart';

import 'labour_request_add_state.dart';

class LabourRequestAddController extends GetxController with DioCancelableMixin {
  final LabourSGRepository _labourRepository = Get.find();
  final LabourRequestAddState state = LabourRequestAddState();

  // 获取添加选项数据
  void fetchLabourRequestAddIndex() async {
    var result = await _labourRepository.fetchLabourRequestAddIndex(
      cancelToken: cancelToken,
    );

    if (result.isSuccess) {
      state.indexEntity = result.data;
      update();
    } else {
      ToastEngine.show(result.errorMsg ?? "Network Load Error".tr);
    }
  }

  @override
  void onReady() {
    super.onReady();
    fetchLabourRequestAddIndex();
  }

  // 选择工标题
  void pickJobTitle() {
    if (state.indexEntity == null) {
      return;
    }

    int selectedTemplateIndex;
    if (state.selectedJobTitleId == null) {
      selectedTemplateIndex = 0;
    } else {
      selectedTemplateIndex = state.indexEntity!.titleList.indexWhere((department) => department.value.toString() == state.selectedJobTitleId);
    }

    if (selectedTemplateIndex < 0) {
      selectedTemplateIndex = 0;
    }

    OptionPickerUtil.showCupertinoOptionPicker(
      items: state.indexEntity!.titleList.map((e) => e.txt!).toList(growable: false),
      initialSelectIndex: selectedTemplateIndex,
      onPickerChanged: (_, index) {
        state.selectedJobTitleId = state.indexEntity!.titleList[index].value!.toString();
        state.selectedJobTitle = state.indexEntity!.titleList[index].txt!.toString();
        update();
      },
    );
  }

  //选择开始时间
  void pickStartTime() {
    if (state.indexEntity == null) {
      return;
    }

    DatePickerUtil.showCupertinoDatePicker(
      selectedDateTime: state.selectedStartTime,
      mode: CupertinoDatePickerMode.dateAndTime,
      onDateTimeChanged: (date) {
        state.selectedStartTime = date;
        update();
      },
      title: "Start Time".tr,
    );
  }

  // 选择结束时间
  void pickEndTime() {
    if (state.indexEntity == null) {
      return;
    }

    DatePickerUtil.showCupertinoDatePicker(
      selectedDateTime: state.selectedEndTime ?? state.selectedStartTime,
      mode: CupertinoDatePickerMode.dateAndTime,
      onDateTimeChanged: (date) {
        state.selectedEndTime = date;
        update();
      },
      title: "End Time".tr,
    );
  }

  void pickRepeatStartTime() {
    if (state.indexEntity == null) {
      return;
    }

    DatePickerUtil.showCupertinoDatePicker(
      selectedDateTime: state.selectedRepeatStartTime,
      mode: CupertinoDatePickerMode.date,
      onDateTimeChanged: (date) {
        state.selectedRepeatStartTime = date;
        update();
      },
      title: "Start Time".tr,
    );
  }

  void pickRepeatEndTime() {
    if (state.indexEntity == null) {
      return;
    }

    DatePickerUtil.showCupertinoDatePicker(
      selectedDateTime: state.selectedRepeatEndTime ?? state.selectedRepeatStartTime,
      mode: CupertinoDatePickerMode.date,
      onDateTimeChanged: (date) {
        state.selectedRepeatEndTime = date;
        update();
      },
      title: "End Time".tr,
    );
  }

  //选择部门
  void pickOutlet() {
    if (state.indexEntity == null) {
      return;
    }

    int selectedIndex;
    if (state.selectedOutletId == null) {
      selectedIndex = 0;
    } else {
      selectedIndex = state.indexEntity!.outletList.indexWhere((department) => department.value.toString() == state.selectedOutletId);
    }

    if (selectedIndex < 0) {
      selectedIndex = 0;
    }

    OptionPickerUtil.showCupertinoOptionPicker(
      items: state.indexEntity!.outletList.map((e) => e.txt!).toList(growable: false),
      initialSelectIndex: selectedIndex,
      onPickerChanged: (_, index) {
        state.selectedOutletId = state.indexEntity!.outletList[index].value!.toString();
        state.selectedOutlet = state.indexEntity!.outletList[index].txt!.toString();
        update();
      },
    );
  }

  // 提交LabourRequest表单
  void doSubmit() async {
    var maleNoController = state.formData['need_male']!['controller'];
    var femaleNoController = state.formData['need_female']!['controller'];
    var needNoController = state.formData['need_no']!['controller'];
    var remarkController = state.formData['remark']!['controller'];

    String maleNo = maleNoController.text.toString();
    String femaleNo = femaleNoController.text.toString();
    String needNo = needNoController.text.toString();
    String remark = remarkController.text.toString();

    if (Utils.isEmpty(state.selectedJobTitleId)) {
      ToastEngine.show("Select Job Title".tr);
      return;
    }

    if (state.selectedStartTime == null) {
      ToastEngine.show("Select Job Start Time".tr);
      return;
    }

    if (state.selectedEndTime == null) {
      ToastEngine.show("Select Job End Time".tr);
      return;
    }

    if (Utils.isEmpty(state.selectedOutletId)) {
      ToastEngine.show("Choose Outlet".tr);
      return;
    }

    if (state.genderOptionType == 0) {
      if (Utils.isEmpty(needNo)) {
        ToastEngine.show("Enter No. of Staff".tr);
        return;
      }
    } else {
      if (Utils.isEmpty(maleNo) || Utils.isEmpty(femaleNo)) {
        ToastEngine.show("Enter No. of Staff of The Corresponding Gender".tr);
        return;
      }
    }

    var result = await _labourRepository.submitLabourRequestAdd(
      state.selectedJobTitleId,
      DateTimeUtils.formatDate(state.selectedStartTime),
      DateTimeUtils.formatDate(state.selectedEndTime),
      DateTimeUtils.formatDate(state.selectedRepeatStartTime, format: "yyyy-MM-dd"),
      DateTimeUtils.formatDate(state.selectedRepeatEndTime, format: "yyyy-MM-dd"),
      state.selectedOutletId,
      state.genderOptionType,
      maleNo,
      femaleNo,
      needNo,
      state.selectRequestTypeId,
      remark,
      cancelToken: cancelToken,
    );

    //处理数据
    if (result.isSuccess) {
      NotifyEngine.showSuccess("Successful".tr);

      //根据类型刷新
      state.cb?.call(true);

      Get.back();
    } else {
      ToastEngine.show(result.errorMsg ?? "Network Load Error".tr);
    }
  }
}
