import 'package:cs_resources/constants/color_constants.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:shared/utils/date_time_utils.dart';
import 'package:shared/utils/screen_util.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/no_shadow_scroll_behavior.dart';
import 'package:widgets/shatter/custom_radio_check.dart';
import 'package:widgets/shatter/form_require_text.dart';
import 'package:widgets/shatter/round_my_text_field.dart';
import 'package:widgets/widget_export.dart';

import 'labour_request_add_controller.dart';

import 'package:plugin_basic/base/base_stateless_page.dart';
import 'package:plugin_basic/utils/ext_get_nav.dart';
import 'package:router/path/router_path.dart';

import 'labour_request_add_state.dart';

class LabourRequestAddPage extends BaseStatelessPage<LabourRequestAddController> {
  LabourRequestAddPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance(void Function(dynamic value)? cb) {
    return Get.start(RouterPath.labourRequestAddSG, arguments: {'cb': cb});
  }

  late LabourRequestAddState state;

  @override
  void initState() {
    state = controller.state;
    state.cb = Get.arguments['cb'] as void Function(dynamic)?;
  }

  @override
  LabourRequestAddController createRawController() {
    return LabourRequestAddController();
  }

  @override
  Widget buildWidget(BuildContext context) {
    return autoCtlGetBuilder(builder: (controller) {
      return Scaffold(
        extendBodyBehindAppBar: true,
        appBar: MyAppBar.appBar(context, "Add Labour Requisition".tr),
        body: SafeArea(
          bottom: true,
          top: false,
          child: Container(
            width: double.infinity,
            height: double.infinity,
            padding: EdgeInsets.only(top: kToolbarHeight + ScreenUtil.getStatusBarH(context) + 1),
            decoration: const BoxDecoration(
              gradient: LinearGradient(
                colors: [
                  Color(0xFF091D44),
                  Color(0xFF245A8A),
                  Color(0xFF7F7CEC),
                ],
                begin: Alignment.topCenter,
                end: Alignment.bottomCenter,
              ),
            ),
            child: Scrollbar(
              child: ScrollConfiguration(
                behavior: NoShadowScrollBehavior(),
                child: SingleChildScrollView(
                  scrollDirection: Axis.vertical,
                  physics: const BouncingScrollPhysics(),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      //工作标题，选择模板
                      FormRequireText(
                        text: "Job Title".tr,
                      ).marginOnly(top: 15),

                      //工作标题
                      Container(
                        padding: const EdgeInsets.only(left: 16, right: 10),
                        margin: const EdgeInsets.only(top: 10),
                        height: 45,
                        decoration: BoxDecoration(
                          color: const Color(0xFF4DCFF6).withOpacity(0.2),
                          borderRadius: const BorderRadius.all(Radius.circular(5)),
                        ),
                        child: Row(
                          mainAxisSize: MainAxisSize.max,
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisAlignment: MainAxisAlignment.start,
                          children: [
                            MyTextView(
                              state.selectedJobTitle ?? "",
                              fontSize: 14,
                              hint: "Choose Job Title".tr,
                              textHintColor: ColorConstants.textGrayAECAE5,
                              isFontMedium: true,
                              textColor: ColorConstants.white,
                            ).expanded(),

                            //下拉选图标
                            const MyAssetImage(Assets.baseServiceTriangleDropDownIcon, width: 11.5, height: 6.28),
                          ],
                        ),
                      ).onTap(() {
                        FocusScope.of(context).unfocus();
                        controller.pickJobTitle();
                      }),

                      //选择工作时间
                      FormRequireText(
                        text: "Job Time".tr,
                      ).marginOnly(top: 15),

                      Row(
                        mainAxisSize: MainAxisSize.max,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        mainAxisAlignment: MainAxisAlignment.start,
                        children: [
                          //选择工作开始时间
                          Expanded(
                            child: Container(
                              padding: const EdgeInsets.only(left: 16, right: 10),
                              height: 45,
                              decoration: BoxDecoration(
                                color: const Color(0xFF4DCFF6).withOpacity(0.2),
                                borderRadius: const BorderRadius.all(Radius.circular(5)),
                              ),
                              child: Row(
                                mainAxisSize: MainAxisSize.max,
                                crossAxisAlignment: CrossAxisAlignment.center,
                                mainAxisAlignment: MainAxisAlignment.start,
                                children: [
                                  MyTextView(
                                    state.selectedStartTime == null ? "" : DateTimeUtils.formatDate(state.selectedStartTime, format: "yyyy-MM-dd HH:mm"),
                                    fontSize: 14,
                                    hint: "Job Start Time".tr,
                                    textHintColor: ColorConstants.textGrayAECAE5,
                                    isFontMedium: true,
                                    textColor: ColorConstants.white,
                                  ).expanded(),
                                  //下拉选图标
                                  const MyAssetImage(Assets.baseServiceTriangleDropDownIcon, width: 11.5, height: 6.28),
                                ],
                              ),
                            ).onTap(() {
                              FocusScope.of(context).unfocus();
                              controller.pickStartTime();
                            }),
                          ),

                          //选择工作结束时间
                          Expanded(
                            child: Container(
                              padding: const EdgeInsets.only(left: 16, right: 10),
                              margin: const EdgeInsets.only(left: 10),
                              height: 45,
                              decoration: BoxDecoration(
                                color: const Color(0xFF4DCFF6).withOpacity(0.2),
                                borderRadius: const BorderRadius.all(Radius.circular(5)),
                              ),
                              child: Row(
                                mainAxisSize: MainAxisSize.max,
                                crossAxisAlignment: CrossAxisAlignment.center,
                                mainAxisAlignment: MainAxisAlignment.start,
                                children: [
                                  MyTextView(
                                    state.selectedEndTime == null ? "" : DateTimeUtils.formatDate(state.selectedEndTime, format: "yyyy-MM-dd HH:mm"),
                                    fontSize: 14,
                                    hint: "Job End Time".tr,
                                    textHintColor: ColorConstants.textGrayAECAE5,
                                    isFontMedium: true,
                                    textColor: ColorConstants.white,
                                  ).expanded(),
                                  //下拉选图标
                                  const MyAssetImage(Assets.baseServiceTriangleDropDownIcon, width: 11.5, height: 6.28),
                                ],
                              ),
                            ).onTap(() {
                              FocusScope.of(context).unfocus();
                              controller.pickEndTime();
                            }),
                          ),
                        ],
                      ).marginOnly(top: 10),

                      //选择重复时间
                      MyTextView(
                        "Repeat".tr,
                        fontSize: 15,
                        isFontRegular: true,
                        textColor: Colors.white,
                        marginTop: 15,
                      ),

                      Row(
                        mainAxisSize: MainAxisSize.max,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        mainAxisAlignment: MainAxisAlignment.start,
                        children: [
                          //选择重复的开始时间
                          Expanded(
                            child: Container(
                              padding: const EdgeInsets.only(left: 16, right: 10),
                              height: 45,
                              decoration: BoxDecoration(
                                color: const Color(0xFF4DCFF6).withOpacity(0.2),
                                borderRadius: const BorderRadius.all(Radius.circular(5)),
                              ),
                              child: Row(
                                mainAxisSize: MainAxisSize.max,
                                crossAxisAlignment: CrossAxisAlignment.center,
                                mainAxisAlignment: MainAxisAlignment.start,
                                children: [
                                  MyTextView(
                                    state.selectedRepeatStartTime == null
                                        ? ""
                                        : DateTimeUtils.formatDate(state.selectedRepeatStartTime, format: "yyyy-MM-dd"),
                                    fontSize: 14,
                                    hint: "Repeat Start Time".tr,
                                    textHintColor: ColorConstants.textGrayAECAE5,
                                    isFontMedium: true,
                                    textColor: ColorConstants.white,
                                  ).expanded(),
                                  //下拉选图标
                                  const MyAssetImage(Assets.baseServiceTriangleDropDownIcon, width: 11.5, height: 6.28),
                                ],
                              ),
                            ).onTap(() {
                              FocusScope.of(context).unfocus();
                              controller.pickRepeatStartTime();
                            }),
                          ),

                          //选择重复的结束时间
                          Expanded(
                            child: Container(
                              padding: const EdgeInsets.only(left: 16, right: 10),
                              margin: const EdgeInsets.only(left: 10),
                              height: 45,
                              decoration: BoxDecoration(
                                color: const Color(0xFF4DCFF6).withOpacity(0.2),
                                borderRadius: const BorderRadius.all(Radius.circular(5)),
                              ),
                              child: Row(
                                mainAxisSize: MainAxisSize.max,
                                crossAxisAlignment: CrossAxisAlignment.center,
                                mainAxisAlignment: MainAxisAlignment.start,
                                children: [
                                  MyTextView(
                                    state.selectedRepeatEndTime == null
                                        ? ""
                                        : DateTimeUtils.formatDate(state.selectedRepeatEndTime, format: "yyyy-MM-dd"),
                                    fontSize: 14,
                                    hint: "Repeat End Time".tr,
                                    textHintColor: ColorConstants.textGrayAECAE5,
                                    isFontMedium: true,
                                    textColor: ColorConstants.white,
                                  ).expanded(),
                                  //下拉选图标
                                  const MyAssetImage(Assets.baseServiceTriangleDropDownIcon, width: 11.5, height: 6.28),
                                ],
                              ),
                            ).onTap(() {
                              FocusScope.of(context).unfocus();
                              controller.pickRepeatEndTime();
                            }),
                          ),
                        ],
                      ).marginOnly(top: 10),

                      //工作选择部门
                      FormRequireText(
                        text: "Outlet".tr,
                      ).marginOnly(top: 15),

                      //选择部门
                      Container(
                        padding: const EdgeInsets.only(left: 16, right: 10),
                        margin: const EdgeInsets.only(top: 10),
                        height: 45,
                        decoration: BoxDecoration(
                          color: const Color(0xFF4DCFF6).withOpacity(0.2),
                          borderRadius: const BorderRadius.all(Radius.circular(5)),
                        ),
                        child: Row(
                          mainAxisSize: MainAxisSize.max,
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisAlignment: MainAxisAlignment.start,
                          children: [
                            MyTextView(
                              state.selectedOutlet ?? "",
                              fontSize: 14,
                              hint: "Choose Outlet".tr,
                              textHintColor: ColorConstants.textGrayAECAE5,
                              isFontMedium: true,
                              textColor: ColorConstants.white,
                            ).expanded(),
                            const MyAssetImage(Assets.baseServiceTriangleDropDownIcon, width: 11.5, height: 6.28),
                          ],
                        ),
                      ).onTap(() {
                        FocusScope.of(context).unfocus();
                        controller.pickOutlet();
                      }),

                      //需要的人数
                      FormRequireText(
                        text: "No. of Staff".tr,
                      ).marginOnly(top: 15),

                      //选择人数类型单选
                      CustomRadioCheck(
                        options: state.genderOptions,
                        onOptionSelected: (index, text) {
                          state.genderOptionType = index;
                          controller.update();
                        },
                        selectedPosition: state.genderOptionType,
                      ).marginOnly(top: 10),

                      //输入框(只允许输入数字)
                      Visibility(
                        visible: state.genderOptionType == 0,
                        child: CustomTextField(
                          formKey: "need_no",
                          marginLeft: 0,
                          marginRight: 0,
                          paddingTop: 0,
                          paddingBottom: 0,
                          height: 45,
                          fillBackgroundColor: const Color(0xFF4DCFF6).withOpacity(0.2),
                          inputFormatters: <TextInputFormatter>[FilteringTextInputFormatter.digitsOnly],
                          textInputType: TextInputType.number,
                          formData: state.formData,
                          textInputAction: TextInputAction.done,
                          onSubmit: (key, value) {
                            FocusScope.of(context).unfocus();
                          },
                          marginTop: 10,
                        ),
                      ),

                      Visibility(
                        visible: state.genderOptionType != 0,
                        child: Row(
                          children: [
                            MyTextView(
                              "Male".tr,
                              fontSize: 15,
                              isFontRegular: true,
                              marginRight: 10,
                              textColor: ColorConstants.textGrayAECAE5,
                            ),
                            CustomTextField(
                              formKey: "need_male",
                              marginLeft: 0,
                              marginRight: 0,
                              paddingTop: 0,
                              paddingBottom: 0,
                              height: 45,
                              fillBackgroundColor: const Color(0xFF4DCFF6).withOpacity(0.2),
                              inputFormatters: <TextInputFormatter>[FilteringTextInputFormatter.digitsOnly],
                              textInputType: TextInputType.number,
                              formData: state.formData,
                              textInputAction: TextInputAction.done,
                              onSubmit: (key, value) {
                                FocusScope.of(context).unfocus();
                              },
                            ).expanded(),
                            MyTextView(
                              "Female".tr,
                              fontSize: 15,
                              isFontRegular: true,
                              marginLeft: 12,
                              marginRight: 10,
                              textColor: ColorConstants.textGrayAECAE5,
                            ),
                            CustomTextField(
                              formKey: "need_female",
                              marginLeft: 0,
                              marginRight: 0,
                              paddingTop: 0,
                              paddingBottom: 0,
                              height: 45,
                              fillBackgroundColor: const Color(0xFF4DCFF6).withOpacity(0.2),
                              inputFormatters: <TextInputFormatter>[FilteringTextInputFormatter.digitsOnly],
                              textInputType: TextInputType.number,
                              formData: state.formData,
                              textInputAction: TextInputAction.done,
                              onSubmit: (key, value) {
                                FocusScope.of(context).unfocus();
                              },
                            ).expanded(),
                          ],
                        ).marginOnly(top: 10),
                      ),

                      //Request Type
                      MyTextView(
                        "Request Type".tr,
                        fontSize: 15,
                        isFontRegular: true,
                        textColor: Colors.white,
                        marginTop: 15,
                      ),

                      //Request Type单选
                      CustomRadioCheck(
                        options: state.indexEntity?.requestType.map((e) => e.txt!).toList() ?? [],
                        onOptionSelected: (index, text) {
                          state.selectRequestTypeId = state.indexEntity!.requestType[index].value;
                        },
                        selectedPosition: state.indexEntity == null ? -1 : 0,
                      ).marginOnly(top: 10),

                      //输入Remark
                      MyTextView(
                        "Remark".tr,
                        fontSize: 15,
                        isFontRegular: true,
                        textColor: Colors.white,
                        marginTop: 15,
                      ),

                      IgnoreKeyboardDismiss(
                        child: Container(
                          height: 160,
                          margin: const EdgeInsets.only(top: 10),
                          padding: const EdgeInsets.symmetric(vertical: 15, horizontal: 15),
                          decoration: BoxDecoration(
                            color: const Color(0xFF4DCFF6).withOpacity(0.2),
                            borderRadius: const BorderRadius.all(Radius.circular(5)),
                          ),
                          child: TextField(
                            cursorColor: ColorConstants.white,
                            cursorWidth: 1.5,
                            autofocus: false,
                            enabled: true,
                            focusNode: state.formData["remark"]!['focusNode'],
                            controller: state.formData["remark"]!['controller'],
                            // 装饰
                            decoration: InputDecoration(
                              isDense: true,
                              isCollapsed: true,
                              border: InputBorder.none,
                              hintText: state.formData["remark"]!['hintText'],
                              hintStyle: const TextStyle(
                                color: ColorConstants.textGrayAECAE5,
                                fontSize: 15.0,
                                fontWeight: FontWeight.w400,
                              ),
                            ),
                            style: const TextStyle(
                              color: ColorConstants.white,
                              fontSize: 15.0,
                              fontWeight: FontWeight.w400,
                            ),
                            // 键盘动作右下角图标
                            textInputAction: TextInputAction.done,
                            onSubmitted: (value) {
                              FocusScope.of(context).unfocus();
                            },
                          ),
                        ),
                      ),

                      //提交按钮
                      MyButton(
                        type: ClickType.throttle,
                        milliseconds: 500,
                        onPressed: () {
                          FocusScope.of(context).unfocus();
                          controller.doSubmit();
                        },
                        text: "Submit".tr,
                        textColor: ColorConstants.white,
                        fontSize: 16,
                        radius: 22.5,
                        backgroundColor: hexToColor("#FFBB1B"),
                        fontWeight: FontWeight.w500,
                      ).marginSymmetric(horizontal: 0, vertical: 30),
                    ],
                  ).paddingOnly(left: 15, right: 15),
                ),
              ),
            ),
          ),
        ),
      );
    });
  }
}
