import 'package:domain/repository/labour_sg_repository.dart';
import 'package:flutter/cupertino.dart';
import 'package:get/get.dart';
import 'package:plugin_platform/engine/loading/loading_engine.dart';
import 'package:plugin_platform/engine/notify/notify_engine.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:plugin_platform/http/dio/dio_cancelable_mixin.dart';
import 'package:shared/utils/date_time_utils.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/util.dart';
import 'package:widgets/picker/date_picker_util.dart';
import 'package:widgets/picker/option_pick_util.dart';

import 'labour_request_edit_state.dart';

class LabourRequestEditController extends GetxController with DioCancelableMixin {
  final LabourSGRepository _labourRepository = Get.find();
  final LabourRequestEditState state = LabourRequestEditState();

  // 获取添加选项数据
  void fetchLabourRequestAddIndex() async {
    LoadingEngine.show();
    var result = await _labourRepository.fetchLabourRequestAddIndex(
      isShowLoadingDialog: false,
      cancelToken: cancelToken,
    );

    if (result.isSuccess) {
      state.indexEntity = result.data;
      update();
    } else {
      ToastEngine.show(result.errorMsg ?? "Network Load Error".tr);
    }

    var result2 = await _labourRepository.fetchLabourRequestEditDetail(
      isShowLoadingDialog: false,
      state.requestId,
      cancelToken: cancelToken,
    );

    LoadingEngine.dismiss();

    if (result2.isSuccess) {
      state.editIndexEntity = result2.data;
      var needMallController = state.formData['need_male']!['controller'];
      var needFemaleController = state.formData['need_female']!['controller'];
      var needNumController = state.formData['need_no']!['controller'];
      var remarkController = state.formData['remark']!['controller'];

      // int genderOptionType = 0;  //使用哪一种类型限制
      if (state.editIndexEntity?.job?.genderNumberLimit == 1) {
        state.genderOptionType = 1;
        needMallController.text = state.editIndexEntity?.job?.maleNumberLimit?.toString();
        needFemaleController.text = state.editIndexEntity?.job?.femaleNumberLimit?.toString();
        needNumController.text = '';
      } else {
        state.genderOptionType = 0;
        needMallController.text = '';
        needFemaleController.text = '';
        needNumController.text = state.editIndexEntity?.job?.needNum?.toString();
      }

      remarkController.text = state.editIndexEntity?.remark ?? '';

      state.selectedJobTitle = state.editIndexEntity?.job?.jobTitle;
      state.selectedJobTitleId = state.editIndexEntity?.job?.jobTitleId?.toString();

      state.selectedStartTime = DateTimeUtils.getDateTime(state.editIndexEntity!.startTime!);
      state.selectedEndTime = DateTimeUtils.getDateTime(state.editIndexEntity!.endTime!);

      state.selectedOutlet = state.editIndexEntity?.job?.outletName;
      state.selectedOutletId = state.editIndexEntity?.job?.outletId?.toString();

      state.selectRequestTypeId = state.editIndexEntity?.job?.requestType?.toString();

      // String? selectRequestTypeId;

      update();
    } else {
      ToastEngine.show(result2.errorMsg ?? "Network Load Error".tr);
    }
  }

  @override
  void onReady() {
    super.onReady();
    fetchLabourRequestAddIndex();
  }

  // 选择工标题
  void pickJobTitle() {
    if (state.indexEntity == null) {
      return;
    }

    int selectedTemplateIndex;
    if (state.selectedJobTitleId == null) {
      selectedTemplateIndex = 0;
    } else {
      selectedTemplateIndex = state.indexEntity!.titleList.indexWhere((department) => department.value.toString() == state.selectedJobTitleId);
    }

    if (selectedTemplateIndex < 0) {
      selectedTemplateIndex = 0;
    }

    OptionPickerUtil.showCupertinoOptionPicker(
      items: state.indexEntity!.titleList.map((e) => e.txt!).toList(growable: false),
      initialSelectIndex: selectedTemplateIndex,
      onPickerChanged: (_, index) {
        state.selectedJobTitleId = state.indexEntity!.titleList[index].value!.toString();
        state.selectedJobTitle = state.indexEntity!.titleList[index].txt!.toString();
        update();
      },
    );
  }

  //选择开始时间
  void pickStartTime() {
    if (state.indexEntity == null) {
      return;
    }

    DatePickerUtil.showCupertinoDatePicker(
      selectedDateTime: state.selectedStartTime,
      mode: CupertinoDatePickerMode.dateAndTime,
      onDateTimeChanged: (date) {
        state.selectedStartTime = date;
        update();
      },
      title: "Start Time".tr,
    );
  }

  // 选择结束时间
  void pickEndTime() {
    if (state.indexEntity == null) {
      return;
    }

    DatePickerUtil.showCupertinoDatePicker(
      selectedDateTime: state.selectedEndTime ?? state.selectedStartTime,
      mode: CupertinoDatePickerMode.dateAndTime,
      onDateTimeChanged: (date) {
        state.selectedEndTime = date;
        update();
      },
      title: "End Time".tr,
    );
  }

  //选择部门
  void pickOutlet() {
    if (state.indexEntity == null) {
      return;
    }

    int selectedIndex;
    if (state.selectedOutletId == null) {
      selectedIndex = 0;
    } else {
      selectedIndex = state.indexEntity!.outletList.indexWhere((department) => department.value.toString() == state.selectedOutletId);
    }

    if (selectedIndex < 0) {
      selectedIndex = 0;
    }

    OptionPickerUtil.showCupertinoOptionPicker(
      items: state.indexEntity!.outletList.map((e) => e.txt!).toList(growable: false),
      initialSelectIndex: selectedIndex,
      onPickerChanged: (_, index) {
        state.selectedOutletId = state.indexEntity!.outletList[index].value!.toString();
        state.selectedOutlet = state.indexEntity!.outletList[index].txt!.toString();
        update();
      },
    );
  }

  // 提交LabourRequest表单
  void doEditSubmit() async {
    var maleNoController = state.formData['need_male']!['controller'];
    var femaleNoController = state.formData['need_female']!['controller'];
    var needNoController = state.formData['need_no']!['controller'];
    var remarkController = state.formData['remark']!['controller'];

    String maleNo = maleNoController.text.toString();
    String femaleNo = femaleNoController.text.toString();
    String needNo = needNoController.text.toString();
    String remark = remarkController.text.toString();

    if (state.selectedStartTime == null) {
      ToastEngine.show("Select Job Start Time".tr);
      return;
    }

    if (state.selectedEndTime == null) {
      ToastEngine.show("Select Job End Time".tr);
      return;
    }

    if (Utils.isEmpty(state.selectedOutletId)) {
      ToastEngine.show("Choose Outlet".tr);
      return;
    }

    if (state.genderOptionType == 0) {
      if (Utils.isEmpty(needNo)) {
        ToastEngine.show("Enter No. of Staff".tr);
        return;
      }
    } else {
      if (Utils.isEmpty(maleNo) || Utils.isEmpty(femaleNo)) {
        ToastEngine.show("Enter No. of Staff of The Corresponding Gender".tr);
        return;
      }
    }

    var result = await _labourRepository.submitLabourRequestEdit(
      state.requestId,
      DateTimeUtils.formatDate(state.selectedStartTime),
      DateTimeUtils.formatDate(state.selectedEndTime),
      state.selectedOutletId,
      state.genderOptionType,
      maleNo,
      femaleNo,
      needNo,
      state.selectRequestTypeId,
      remark,
      cancelToken: cancelToken,
    );

    //处理数据
    if (result.isSuccess) {
      NotifyEngine.showSuccess("Successful".tr);

      //根据类型刷新
      state.cb?.call(true);

      Get.back();
    } else {
      ToastEngine.show(result.errorMsg ?? "Network Load Error".tr);
    }
  }
}
